summaryrefslogtreecommitdiffstats
path: root/pyload/remote
diff options
context:
space:
mode:
Diffstat (limited to 'pyload/remote')
-rw-r--r--pyload/remote/ThriftBackend.py10
-rw-r--r--pyload/remote/socketbackend/create_ttypes.py4
-rw-r--r--pyload/remote/thriftbackend/Processor.py2
-rw-r--r--pyload/remote/thriftbackend/ThriftClient.py4
-rw-r--r--pyload/remote/thriftbackend/ThriftTest.py4
5 files changed, 12 insertions, 12 deletions
diff --git a/pyload/remote/socketbackend/create_ttypes.py b/pyload/remote/socketbackend/create_ttypes.py
index be1e2aaea..cf357bd53 100644
--- a/pyload/remote/socketbackend/create_ttypes.py
+++ b/pyload/remote/socketbackend/create_ttypes.py
@@ -7,8 +7,8 @@ from os.path import abspath, dirname, join
sys.path.append(join(pypath, "pyload", "lib"))
sys.path.append(join(pypath, "pyload", "remote"))
-from thriftbackend.thriftgen.pyload import ttypes
-from thriftbackend.thriftgen.pyload.Pyload import Iface
+from pyload.remote.thriftbackend.thriftgen.pyload import ttypes
+from pyload.remote.thriftbackend.thriftgen.pyload.Pyload import Iface
def main():
diff --git a/pyload/remote/thriftbackend/Processor.py b/pyload/remote/thriftbackend/Processor.py
index a8b87c82c..683697d1c 100644
--- a/pyload/remote/thriftbackend/Processor.py
+++ b/pyload/remote/thriftbackend/Processor.py
@@ -1,6 +1,6 @@
# -*- coding: utf-8 -*-
-from thriftgen.pyload import Pyload
+from pyload.remote.thriftbackend.thriftgen.pyload import Pyload
class Processor(Pyload.Processor):
def __init__(self, *args, **kwargs):
diff --git a/pyload/remote/thriftbackend/ThriftClient.py b/pyload/remote/thriftbackend/ThriftClient.py
index d7b0d2919..d5159320e 100644
--- a/pyload/remote/thriftbackend/ThriftClient.py
+++ b/pyload/remote/thriftbackend/ThriftClient.py
@@ -17,8 +17,8 @@ from Protocol import Protocol
# modules should import ttypes from here, when want to avoid importing API
-from thriftgen.pyload import Pyload
-from thriftgen.pyload.ttypes import *
+from pyload.remote.thriftbackend.thriftgen.pyload import Pyload
+from pyload.remote.thriftbackend.thriftgen.pyload.ttypes import *
ConnectionClosed = TTransport.TTransportException
diff --git a/pyload/remote/thriftbackend/ThriftTest.py b/pyload/remote/thriftbackend/ThriftTest.py
index 7243cc6f2..05c6ba40e 100644
--- a/pyload/remote/thriftbackend/ThriftTest.py
+++ b/pyload/remote/thriftbackend/ThriftTest.py
@@ -6,8 +6,8 @@ from os.path import join, abspath, dirname
path = join((abspath(dirname(__file__))), "..", "..", "lib")
sys.path.append(path)
-from thriftgen.pyload import Pyload
-from thriftgen.pyload.ttypes import *
+from pyload.remote.thriftbackend.thriftgen.pyload import Pyload
+from pyload.remote.thriftbackend.thriftgen.pyload.ttypes import *
from Socket import Socket
from thrift import Thrift
diff --git a/pyload/remote/ThriftBackend.py b/pyload/remote/ThriftBackend.py
index 7c76c4231..2b46e25c0 100644
--- a/pyload/remote/ThriftBackend.py
+++ b/pyload/remote/ThriftBackend.py
@@ -5,11 +5,11 @@ from os.path import exists
from pyload.manager.RemoteManager import BackendBase
-from thriftbackend.Processor import Processor
-from thriftbackend.Protocol import ProtocolFactory
-from thriftbackend.Socket import ServerSocket
-from thriftbackend.Transport import TransportFactory
-#from thriftbackend.Transport import TransportFactoryCompressed
+from pyload.remote.thriftbackend.Processor import Processor
+from pyload.remote.thriftbackend.Protocol import ProtocolFactory
+from pyload.remote.thriftbackend.Socket import ServerSocket
+from pyload.remote.thriftbackend.Transport import TransportFactory
+#from pyload.remote.thriftbackend.Transport import TransportFactoryCompressed
from thrift.server import TServer